@@ -28,7 +28,7 @@ def is_begin_one_hour(now_date):
     hour = now_date.hour
     minute = now_date.minute
     return ((hour == 9 and minute >= 30) or
-            (hour <= 10 and minute < 30))
+            (hour == 10 and minute < 30))
 
 
 def is_end_trade_ten_minute(now_date):
@@ -74,13 +74,14 @@ def is_trade_time(now_date):
     str_now_day = now_date.strftime('%Y-%m-%d')
     is_trade_day = is_trade_date(str_now_day)
     trade_time = (hour == 9 and minute == 25 and second > 20) \
-                 or (hour == 9 and minute == 26 and second < 10) \
+                 or (hour == 9 and minute == 26 and second < 20) \
                  or (hour == 9 and minute >= 30) \
                  or (hour == 10) \
-                 or (hour == 11 and minute <= 30) \
+                 or (hour == 11 and minute < 30) \
+                 or (hour == 11 and minute == 30 and second < 5) \
                  or (hour == 13) \
-                 or (hour == 14) \
-                 or (hour == 15 and minute < 1)
+                 or (hour == 14 and minute < 57) \
+                 or (hour == 15 and minute == 0 and second < 10)
 
     return is_trade_day and trade_time
 
@@ -156,6 +157,7 @@ def lash_date(date_str):
     return date_str
 
 
+# 已经交易的时间
 def calculate_had_trade_minute(now_date):
     hour = now_date.hour
     minute = now_date.minute
@@ -208,9 +210,9 @@ def last_day_of_week(date):
 def last_day_month(date):
     month = date.month
     day = date.day
-    if month in [1, 3, 5, 7, 8, 12] and day == 31:
+    if month in [1, 3, 5, 7, 8, 10, 12] and day == 31:
         return True
-    elif month in [4, 6, 9, 10, 11] and day == 30:
+    elif month in [4, 6, 9, 11] and day == 30:
         return True
     elif run_nian(date) and month == 2 and day == 29:
         return True
